@@ -42,6 +42,14 @@ class TrainingPlan(Object):
             assoc.training_plan=self
         return assocs
 
+    @property
+    @lazy
+    def user_associations(self):
+        assocs = self._client.Listing(self._client.TrainingPlanUser, endpoint=f"/trainingplans/{self.guid}/users")
+        for assoc in assocs:
+            assoc.training_plan=self
+        return assocs
+
     @property
     @lazy
     def records(self):
@@ -100,6 +108,9 @@ class TrainingPlan(Object):
 
 
 class TrainingPlanItem(Object):
+
+    def __repr__(self):
+
     
     @property
     @lazy
